audits/dependencies/unused_dependency_audit library

Classes

UnusedDependencyAudit
Flags direct pub.dev dependencies declared in pubspec.yaml that no Dart file in the project imports or exports. Unused dependencies add unnecessary size to the app and bloat the dependency tree.