ProjectContext class

Represents the Flutter project being audited.

Constructors

ProjectContext({required Directory rootDirectory})
const

Properties

androidAppBuildGradle File
android/app/build.gradle (Groovy DSL)
no setter
androidAppBuildGradleKts File
android/app/build.gradle.kts (Kotlin DSL)
no setter
androidDirectory Directory
android directory
no setter
androidKeyProperties File
android/key.properties
no setter
androidManifest File
AndroidManifest.xml
no setter
gitignore File
.gitignore at the project root
no setter
hashCode int
The hash code for this object.
no setterinherited
ignoreConfigFile File
Project-level suppression config for flutter_auditor findings.
no setter
iosDirectory Directory
ios directory
no setter
iosInfoPlist File
Info.plist
no setter
libDirectory Directory
lib directory
no setter
pubspec File
pubspec.yaml
no setter
pubspecLock File
pubspec.lock
no setter
rootDirectory Directory
Root directory of the Flutter project.
final
rootPath String
Absolute path to the project.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited