Severity enum

Represents the severity level of a security issue.

Inheritance
Available extensions

Values

critical → const Severity
high → const Severity
medium → const Severity
low → const Severity
info → const Severity

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
Human-readable name.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isAtLeastAsSevereAs(Severity threshold) bool
True if this severity is at least as severe as threshold (lower index in Severity.values means more severe: critical is the most severe, info the least).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Severity>
A constant List of the values in this enum, in order of their declaration.