BaselineHelper class

Loads and writes a project's .flutter_auditor_baseline.json.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load(ProjectContext context) Future<BaselineConfig>
write(List<AuditRunResult> results, ProjectContext context) Future<void>
Writes results to the project's baseline file, overwriting any existing baseline.