InfoPlistHelper class

Parses an Info.plist (Apple property list XML) into a plain Dart map.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

load(ProjectContext context) → Future<Map<String, dynamic>?>
loadFile(File plist) → Future<Map<String, dynamic>?>
Parses any XML property list file (e.g. PrivacyInfo.xcprivacy). Returns null if the file is missing or is not a valid XML plist.