PubspecHelper class

Reads dependency names declared in a project's pubspec.yaml.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

loadAssetPaths(ProjectContext context) Future<List<String>>
Reads flutter.assets paths declared in a project's pubspec.yaml. Entries ending in / are asset directories; others are individual files.
loadDependencyNames(ProjectContext context) Future<Set<String>>