LockedDependency class
A single resolved entry from pubspec.lock.
Constructors
- LockedDependency({required String name, required String version, required String source, required String dependencyType})
-
const
Properties
- dependencyType → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirectMain → bool
-
True for packages declared directly in pubspec.yaml's
dependencies:(as opposed to dev_dependencies or transitive dependencies pulled in by something else).no setter - isHosted → bool
-
True for ordinary pub.dev-hosted packages (as opposed to sdk, path,
or git dependencies, which pub.dev has no meaningful listing for).
no setter
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited