PatternRule class
Describes a regex-based rule used to flag insecure code in source files.
Constructors
- PatternRule({required String name, required RegExp pattern, required Severity severity, required String recommendation})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited