PermissionInfo class
Constructors
- PermissionInfo({required String permission, required PermissionRisk risk, required String category, required String reason, required String recommendation})
-
const
Properties
- category → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission → String
-
final
- reason → String
-
final
- recommendation → String
-
final
- risk → PermissionRisk
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited