SecretPattern class
Describes a pattern used to detect a hardcoded secret in source code.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGeneric → bool
-
Generic patterns (keyword + assigned string literal) are suppressed on
a line where a more specific pattern already matched, to avoid noise.
final
- name → String
-
final
- pattern → RegExp
-
final
- recommendation → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → Severity
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited