UsageDescriptionRule class
Describes an Info.plist usage-description key checked by UsageDescriptionAudit.
Constructors
Properties
- capability → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
final
- recommendation → String
-
final
-
requiredByPackages
→ List<
String> -
pubspec.yaml dependency names that require this key to be present.
final
-
requiresAlsoPresent
→ List<
String> -
Other usage-description keys that Apple requires to also be present
whenever this key is present (e.g. "Always" location requires
"When In Use" location too).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited