Audit class abstract

Base contract for all security audits.

Implementers

Constructors

Audit()

Properties

description String
Short description of what this audit checks.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the audit.
no setter
name String
Human-readable audit name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(ProjectContext context) Future<AuditResult>
Executes the audit.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited