AuditResult class

Represents the result of a security audit.

Constructors

AuditResult({required List<SecurityIssue> issues})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasIssues → bool
Returns true if the audit found any issues.
no setter
issues → List<SecurityIssue>
Security issues found during the audit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited