SecurityIssue class

Represents a security issue found during an audit.

Constructors

SecurityIssue({required String id, required String title, required String description, required Severity severity, required String file, int? line, required String recommendation})
const

Properties

description String
Detailed description of the issue.
final
file String
File where the issue was found.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the issue.
final
line int?
Line number (if available).
final
recommendation String
Recommendation to resolve the issue.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity Severity
Severity level.
final
title String
Short title of the issue.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited